pub struct MelSpectrogram { /* private fields */ }Expand description
Mel spectrogram extractor.
Pre-computes DFT basis vectors, Hann window, and mel filterbank on
construction so that repeated calls to compute are fast.
Implementations
Sourceimpl MelSpectrogram
impl MelSpectrogram
Sourcepub fn new(config: MelConfig, device: &Device) -> TtsResult<Self>
pub fn new(config: MelConfig, device: &Device) -> TtsResult<Self>
Create a new mel spectrogram extractor.